The dmatest module parameter 'timeout' is documented as accepting a
-1 to mean "infinite timeout". Howver, an infinite timeout is not
advised, nor possible since the module parameter is an unsigned int,
which won't accept a negative value. Change the parameter
comment to reflect current behavior, which allows values from 0 up to
4294967295 (0xFFFFFFFF).

Signed-off-by: Gary R Hook <gary.h...@amd.com>
---
 drivers/dma/dmatest.c |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/drivers/dma/dmatest.c b/drivers/dma/dmatest.c
index b96814a7dceb..e0c229aa1353 100644
--- a/drivers/dma/dmatest.c
+++ b/drivers/dma/dmatest.c
@@ -65,7 +65,7 @@ MODULE_PARM_DESC(pq_sources,
 static int timeout = 3000;
 module_param(timeout, uint, S_IRUGO | S_IWUSR);
 MODULE_PARM_DESC(timeout, "Transfer Timeout in msec (default: 3000), "
-                "Pass -1 for infinite timeout");
+                "Pass 0xFFFFFFFF (4294967295) for maximum timeout");
 
 static bool noverify;
 module_param(noverify, bool, S_IRUGO | S_IWUSR);
@@ -97,7 +97,7 @@ MODULE_PARM_DESC(transfer_size, "Optional custom transfer 
size in bytes (default
  * @iterations:                iterations before stopping test
  * @xor_sources:       number of xor source buffers
  * @pq_sources:                number of p+q source buffers
  * @timeout:           transfer timeout in msec, -1 for infinite timeout
  */
 struct dmatest_params {
        unsigned int    buf_size;
@@ -108,7 +108,7 @@ struct dmatest_params {
        unsigned int    iterations;
        unsigned int    xor_sources;
        unsigned int    pq_sources;
-       int             timeout;
+       unsigned int    timeout;
        bool            noverify;
        bool            norandom;
        int             alignment;
@@ -97,7 +97,7 @@ MODULE_PARM_DESC(transfer_size, "Optional custom transfer 
  * @xor_sources:       number of xor source buffers
  * @pq_sources:                number of p+q source buffers
- * @timeout:           transfer timeout in msec, -1 for infinite timeout
+ * @timeout:           transfer timeout in msec, 0 - 0xFFFFFFFF (4294967295)
  */
 struct dmatest_params {

Reply via email to